Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Executor ¶
type Executor interface {
// Execute runs the query and stores results in dest (must be a pointer to a slice)
// Example: var users []User; executor.Execute(ctx, q, &users)
Execute(ctx context.Context, q *query.Query, dest interface{}) (*query.Result, error)
// Name returns the name of this executor
Name() string
// Close cleans up any resources used by the executor
Close() error
}
Executor is the interface that all database-specific executors must implement
Click to show internal directories.
Click to hide internal directories.